#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
#include <avr/power.h>
#endif

const int sampleWindow = 50;
unsigned int sample;
 
#define SENSOR_PIN A0

#define PIN 6 
#define NUMPIXELS 2

Adafruit_NeoPixel pixels(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);


void setup() 
{
  pinMode (SENSOR_PIN, INPUT); 
    
  #if defined(__AVR_ATtiny85__) && (F_CPU == 16000000)
    clock_prescale_set(clock_div_1);

  #endif
    pixels.begin();
    Serial.begin(9600);
}

void loop() {
  pixels.clear(); // Set all pixel colors to 'off'

  unsigned long startMillis= millis();                   // Start of sample window
  float peakToPeak = 0;                                  // peak-to-peak level
 
  unsigned int signalMax = 0;                            //minimum value
  unsigned int signalMin = 1024; 

   while (millis() - startMillis < sampleWindow)
   {
      sample = analogRead(SENSOR_PIN);                    //get reading from microphone
      if (sample < 1024)                                  // toss out spurious readings
      {
         if (sample > signalMax)
         {
            signalMax = sample;                           // save just the max levels
         }
         else if (sample < signalMin)
         {
            signalMin = sample;                           // save just the min levels
         }
      }
   }


  peakToPeak = signalMax - signalMin;                    // max - min = peak-peak amplitude
  int db = map(peakToPeak,20,900,49.5,90);             //calibrate for deciBels

  Serial.print("Loudness: ");                           //prints to serial 
  Serial.print(db);
  Serial.println("dB");


  if (db > 70)                                         //uses db value to change and display the color of the LEDs
  {
    pixels.setPixelColor(0, pixels.Color(150, 0, 0));;
    pixels.setPixelColor(1, pixels.Color(150, 0, 0));;
    pixels.show();
  }
  else if (db < 52)
  {
    pixels.setPixelColor(0, pixels.Color(0, 150, 0));;    
    pixels.setPixelColor(1, pixels.Color(0, 150, 0));;
    pixels.show();
  }

  delay(100); 
}

